@@ -1,20 +1,21 @@
 package AFS::VLDB;
 #------------------------------------------------------------------------------
-# RCS-Id: "@(#)$Id: VLDB.pm 625 2004-05-05 13:30:16Z nog $"
+# RCS-Id: "@(#)$Id: VLDB.pm 662 2005-02-12 17:14:10Z nog $"
 #
-# Copyright  2003-2004 Alf Wachsmann <alfw@slac.stanford.edu> and
+# Copyright  2003-2005 Alf Wachsmann <alfw@slac.stanford.edu> and
 #                       Norbert E. Gruener <nog@MPA-Garching.MPG.de>
 #
 # This library is free software; you can redistribute it and/or modify it
 # under the same terms as Perl itself.
 #------------------------------------------------------------------------------
 
+use Carp;
 use AFS ();
 
 use vars qw(@ISA $VERSION);
 
 @ISA     = qw(AFS);
-$VERSION = do{my@r=q/Major Version 2.2 $Rev: 625 $/=~/\d+/g;$r[1]-=0;sprintf'%d.'.'%d'.'.%02d'x($#r-1),@r;};
+$VERSION = do{my@r=q/Major Version 2.4 $Rev: 662 $/=~/\d+/g;$r[1]-=0;sprintf'%d.'.'%d'.'.%02d'x($#r-1),@r;};
 
 sub DESTROY {
     my (undef, undef, undef, $subroutine) = caller(1);
@@ -29,13 +30,22 @@ sub delentry {
 
     $noexec = 0 unless $noexec;
 
-    if (ref($volume) eq 'SCALAR' or ref($volume) eq '' ) {
+    if (! defined $volume) {
+        carp "AFS::VLDB->delentry: no VOLUME specified ...\n";
+        return (undef, undef);
+    }
+
+    if (ref($volume) eq 'ARRAY') {
+        $self->_delentry($volume, '', '', '', $noexec);
+    }
+    elsif (ref($volume) eq '' ) {
         my @volumes;
         $volumes[0] = $volume;
         $self->_delentry(\@volumes, '', '', '', $noexec);
     }
     else {
-        $self->_delentry($volume, '', '', '', $noexec);
+        carp "AFS::VLDB->delentry: not a valid input ...\n";
+        return (undef, undef);
     }
 }
 
